interface IUser {
    userId: string;
    userName: string;
    headerImg: string;
    nickName: string;
    signature: string;
    countryCode: string;
    phoneNumber: string;
    bind: boolean;
    playTime: number;
    playCount: number;
    gold: number;
    playDays: number;
    age: number;
    sex: string;
    desc: string;
    birthday: string;
    isMember: boolean;
    allowPay: boolean;
    memberStartTime: string;
    memberEndTime: string;
    mark: number;
    trialState: -1 | 0 | 1 | 2;
    vipState: -1 | 1 | 2;
    giveDays: number;
}
/**
 * 查询用户信息
 * @param session [string] 用户session
 * @returns 用户信息 promise<IUser>
 */
export declare const API_get_userinfo: (session?: string) => Promise<IUser>;
/**
 * 修改用户昵称
 * @param nickname 昵称
 * @returns 是否修改成功 promise<boolean>
 */
export declare const API_update_nickname: (nickname: string) => Promise<boolean>;
/**
 * 修改用户签名
 * @param signature 用户签名
 * @returns 是否修改成功 promise<boolean>
 */
export declare const API_update_signature: (signature: string) => Promise<boolean>;
/**
 * 绑定手机号码
 * @param mobileNumber 用户手机号码
 * @param verifyCode 验证码
 * @returns 是否绑定成功 promise<boolean>
 */
export declare const API_update_mobile: (mobileNumber: string, verifyCode: string) => Promise<boolean>;
/**
 * 修改用户头像
 * @param type 图片来源 图库: image 拍照: photo
 * @returns 修改后的头像路径 promise<string>
 */
export declare const API_update_headerimg: (type: string) => Promise<string>;
/**
 * 修改用户性别
 * @param sex 性别
 * @returns 是否修改成功 promise<boolean>
 */
export declare const API_update_userSex: (sex: string) => Promise<boolean>;
/**
 * 修改用户生日
 * @param birthday 生日
 * @returns 是否修改成功 promise<boolean>
 */
export declare const API_update_birthday: (birthday: string) => Promise<boolean>;
/**
 * 修改密码
 * @param mobile [string] 手机号码
 * @param password [string] 密码
 * @param verifyCode [string] 验证码
 * @param countryCode [string] 国家编号
 * @returns 是否修改成功 promise<boolean>
 */
export declare const API_update_password: (mobile: string, password: string, verifyCode: string, countryCode: string) => Promise<string | boolean>;
/**
 * 注销账号
 * @returns void
 */
export declare const API_set_preLogout: () => Promise<void>;
/**
 * 取消注销账号
 * @returns void
 */
export declare const API_set_cancelLogout: () => Promise<void>;
/**
 * 获取账号注销状态
 * @returns 注销状态['null' | 'create' | 'logout'] 未注销 | 已存在注销请求 | 已注销完成
 */
export declare const API_get_logoutStatus: () => Promise<"create" | "logout" | null>;
export {};
